import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "./view"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Диалог сканирования QR-кода
 */
FullscreenDialog {
    id: dialog
    withBottomPanel: params.context !== Context.Authentication

    property DialogEventFilter eventFilter: DialogEventFilter {
        onKeyboardData: (data, rawData, source) => handler.input(data, rawData, source)
    }

    RowLayout {
        anchors.fill: parent
        spacing: 0
        Rectangle {
            color: Style.parameter("color.modalBackground")
            Layout.fillWidth: true
            Layout.fillHeight: true
            ColumnLayout {
                anchors.centerIn: parent
                spacing: 0
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "employeeMarkScanQrTitle"
                    Tr { tr: params.title }
                }
                Item {
                    Layout.preferredHeight: 16
                }
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "employeeMarkScanQrMessage"
                    Tr { tr: params.message }
                }
                Item {
                    Layout.preferredHeight: 96
                }
                Image {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredHeight: 396
                    source: Style.parameter("icon.qrCodePhone")
                    fillMode: Image.PreserveAspectFit
                    Component.onCompleted: mainWindow.scaleImage(this)
                }
                Item {
                    Layout.preferredHeight: 116
                }
            }
            BasicButton {
                Style.class: "employeeMarkBack"
                anchors {
                    bottom: parent.bottom
                    right: parent.right
                    rightMargin: 24
                    bottomMargin: 24
                }
                width: 124; height: 68
                Tr { code: "employeeMarkButtonCancel"; defaultMessage: "Отмена" }
                onClicked: handler.sendAnswer("", InputSource.Ui)
            }
        }
    }

    DialogHandler { id: handler }
}
