import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "view"

import Artix.Handlers
import Artix.Core
import Artix.Gui

/**
 * @brief Форма информации о лицензии
 */
FullscreenDialog {

    component InfoBox: GroupBox {
        Style.class: "licenseInfoCommonData"
        interactive: false
        leftPadding: 32
        topPadding: 24
        rightPadding: 32
        bottomPadding: 24
    }

    contentItem: RowLayout {
        spacing: 0
        Rectangle {
            id: contentRect
            Layout.fillWidth: true
            Layout.fillHeight: true
            color: Style.parameter("color.modalBackground")
            Flickable {
                id: flickable
                anchors.fill: parent
                contentHeight: content.implicitHeight + 24
                interactive: contentHeight > (contentRect.height)
                ColumnLayout {
                    id: content
                    anchors {
                        left: parent.left; right: parent.right; top: parent.top
                        leftMargin: 24; topMargin: 16; rightMargin: 24
                    }
                    spacing: 16
                    BasicLabel {
                        Style.class: "licenseInfoTitle"
                        Tr { code: "licenseInfoTitle"; defaultMessage: "Информация о лицензии" }
                    }
                    Item { Layout.preferredHeight: 0 } // двойной spacing
                    RowLayout {
                        spacing: 16
                        GroupBox {
                            Style.class: "licenseInfoMainData"
                            Layout.preferredWidth: 240
                            Layout.preferredHeight: keyInfoBox.implicitHeight
                            interactive: false
                            ColumnLayout {
                                anchors {
                                    top: parent.top; right: parent.right; left: parent.left
                                    topMargin: 24; leftMargin: 32; rightMargin: 32
                                }
                                spacing: 4
                                BasicLabel {
                                    Style.class: "licenseInfoCommonLabel"
                                    Tr { code: "licenseInfoStatus"; defaultMessage: "Статус проверки" }
                                }
                                BasicLabel {
                                    elide: Text.ElideRight
                                    Layout.preferredHeight: 120
                                    Style.class: {
                                        if (params.licenseData.errorStatus)
                                            return "licenseInfoStatusError"
                                        return "licenseInfoStatusSuccess"
                                    }
                                    Layout.fillWidth: true
                                    Tr { tr: params.licenseData.status }
                                }
                            }
                        }
                        InfoBox {
                            id: keyInfoBox
                            Layout.fillWidth: true
                            contentItem: ColumnLayout {
                                spacing: 4
                                BasicLabel {
                                    Style.class: "licenseInfoCommonLabel"
                                    Tr { code: "licenseInfoKey"; defaultMessage: "Ключ" }
                                }
                                BasicLabel {
                                    Style.class: "licenseInfoCommonValue"
                                    Layout.fillWidth: true
                                    text: params.licenseData.key
                                }
                                Item {
                                    Layout.preferredHeight: 20
                                }
                                RowLayout {
                                    spacing: 16
                                    ColumnLayout {
                                        BasicLabel {
                                            Style.class: "licenseInfoCommonLabel"
                                            Tr { code: "licenseInfoKeyType"; defaultMessage: "Тип ключа" }
                                        }
                                        BasicLabel {
                                            Style.class: "licenseInfoCommonValue"
                                            text: params.licenseData.keyType
                                        }
                                    }
                                    ColumnLayout {
                                        BasicLabel {
                                            Style.class: "licenseInfoCommonLabel"
                                            Tr { code: "licenseInfoProduct"; defaultMessage: "Продукт" }
                                        }
                                        BasicLabel {
                                            Style.class: "licenseInfoCommonValue"
                                            text: params.licenseData.product
                                        }
                                    }
                                    ColumnLayout {
                                        BasicLabel {
                                            Style.class: "licenseInfoCommonLabel"
                                            Tr { code: "licenseInfoVersion"; defaultMessage: "Версия" }
                                        }
                                        BasicLabel {
                                            Style.class: "licenseInfoCommonValue"
                                            text: params.licenseData.version
                                        }
                                    }
                                }
                            }
                        }
                    }
                    RowLayout {
                        spacing: 16
                        InfoBox {
                            Layout.preferredWidth: content.implicitWidth / 2
                            contentItem: ColumnLayout {
                                spacing: 4
                                BasicLabel {
                                    Style.class: "licenseInfoCommonLabel"
                                    Tr { code: "licenseInfoExpDate"; defaultMessage: "Дата окончания" }
                                }
                                BasicLabel {
                                    Style.class: "licenseInfoCommonValue"
                                    Layout.fillWidth: true
                                    text: params.licenseData.expDate
                                }
                            }
                        }
                        InfoBox {
                            Layout.fillWidth: true
                            contentItem: ColumnLayout {
                                spacing: 4
                                BasicLabel {
                                    Style.class: "licenseInfoCommonLabel"
                                    Tr { code: "licenseInfoBuildDate"; defaultMessage: "Дата окончания договора" }
                                }
                                BasicLabel {
                                    Style.class: "licenseInfoCommonValue"
                                    Layout.fillWidth: true
                                    text: params.licenseData.buildDate
                                }
                            }
                        }
                    }
                    InfoBox {
                        Layout.fillWidth: true
                        Layout.maximumWidth: parent.width
                        contentItem: ColumnLayout {
                            spacing: 4
                            BasicLabel {
                                Style.class: "licenseInfoCommonLabel"
                                Tr { code: "licenseInfoPath"; defaultMessage: "Файл" }
                            }
                            BasicLabel {
                                Style.class: "licenseInfoCommonValue"
                                Layout.fillWidth: true
                                text: params.licenseData.path
                            }
                        }
                    }
                    InfoBox {
                        Layout.fillWidth: true
                        Layout.maximumWidth: parent.width
                        contentItem: ColumnLayout {
                            spacing: 4
                            BasicLabel {
                                Style.class: "licenseInfoCommonLabel"
                                Tr { code: "licenseInfoFeatures"; defaultMessage: "Модули" }
                            }
                            BasicLabel {
                                Style.class: "licenseInfoCommonValue"
                                Layout.fillWidth: true
                                text: params.licenseData.features
                            }
                        }
                    }
                    InfoBox {
                        Layout.fillWidth: true
                        visible: params.licenseData.fr.length > 0
                        contentItem: ColumnLayout {
                            spacing: 4
                            BasicLabel {
                                Style.class: "licenseInfoCommonLabel"
                                Tr { code: "licenseInfoFr"; defaultMessage: "Номер версии ВК" }
                            }
                            BasicLabel {
                                Style.class: "licenseInfoCommonValue"
                                Layout.fillWidth: true
                                text: params.licenseData.fr
                            }
                        }
                    }
                }
                ScrollBar.vertical: ScrollBar {
                    id: scrollBar
                    Timer {
                        id: scrollTimer
                        interval: 2500
                        onTriggered: parent.active = false
                    }
                    onActiveChanged: scrollTimer.start()
                }
            }
        }
        Item {
            Layout.fillHeight: true
            Layout.preferredWidth: 304
            TopPanel {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: true
            }
            ColumnLayout {
                anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: 24 }
                spacing: 8
                BasicButton {
                    Style.class: "licenseInfoCancel"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 68
                    Tr { code: "backButton"; defaultMessage: "Назад" }
                    onClicked: handler.sendAnswer()
                }
            }
        }
    }

    DialogHandler { id: handler }
}
