import QtQuick
import QtQuick.Controls.impl
import QtQuick.Templates as T

import Artix.Gui

T.CheckBox {
    id: control
    Style.type: "checkBox"
    Style.class: "default"

    font: Style.text.font
    property alias iconSource: image.source

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding,
                             implicitIndicatorHeight + topPadding + bottomPadding)

    padding: 16
    spacing: 16

    indicator: Rectangle {
        implicitWidth: 32
        implicitHeight: 32

        anchors {
            left: control.mirrored ? undefined : control.left
            right: !control.mirrored ? undefined : control.right
            leftMargin: control.leftPadding; rightMargin: control.rightPadding
            verticalCenter: parent.verticalCenter
        }

        color: control.Style.indicator.background.color
        radius: control.Style.indicator.background.radius
        border {
            color: control.Style.indicator.background.border.color
            width: control.Style.indicator.background.border.width
        }

        ColorImage {
            id: image
            x: (parent.width - width) / 2
            y: (parent.height - height) / 2
            color: control.Style.indicator.content.color
            source: Style.parameter("icon.checkBox")
            visible: control.checkState === Qt.Checked
        }

        Behavior on color { ColorAnimation { duration: 200 } }
    }

    contentItem: CheckLabel {
        leftPadding: !control.mirrored ? control.indicator.width + control.spacing : 0
        rightPadding: control.mirrored ? control.indicator.width + control.spacing : 0
        text: control.text
        font: control.font
        color: control.Style.text.color
        wrapMode: Text.Wrap
    }

    background: Rectangle {
        color: control.Style.background.color
        border.color: control.Style.background.border.color
        border.width: control.Style.background.border.width
        radius: control.Style.background.radius

        Behavior on color { ColorAnimation { duration: 150 }}
    }
}
