import QtQuick
import QtQuick.Controls
import QtQuick.Controls.impl
import QtQuick.Templates as T

import Artix.Gui
import Artix.Core

/**
 * @brief Поле ввода текста
 * @param hideCursor скрывать курсор при вводе текста
 * @param fixedCursorPosition зафиксировать курсор в конце поля ввода
 */
T.TextField {
    id: control
    Style.type: "textField"
    Style.class: "default"

    property bool hideCursor: false
    property bool fixedCursorPosition: false
    property bool down: tapHandler.pressed
    property alias pressed: tapHandler.pressed
    property Text placeholder: placeholder
    signal clicked()

    implicitWidth: implicitBackgroundWidth + leftInset + rightInset
                   || Math.max(contentWidth, placeholder.implicitWidth) + leftPadding + rightPadding
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             contentHeight + topPadding + bottomPadding,
                             placeholder.implicitHeight + topPadding + bottomPadding)
    padding: 0
    inputMethodHints: Qt.ImhNoAutoUppercase | Qt.ImhNoPredictiveText
    font: Style.text.font
    color: Style.text.color
    // cursorVisible принимает значение true при получении фокуса
    onCursorVisibleChanged: if (hideCursor && cursorVisible) cursorVisible = false
    onCursorPositionChanged: if (fixedCursorPosition) cursorPosition = text.length

    selectionColor: control.palette.highlight
    selectedTextColor: control.palette.highlightedText
    placeholderTextColor: Style.placeholder.color
    verticalAlignment: TextInput.AlignVCenter

    Text {
        id: placeholder
        anchors { fill: control; margins: control.padding }
        // для placeholder'а отдельный alignment текста
        horizontalAlignment: Text.AlignLeft
        verticalAlignment: Text.AlignBottom
        text: control.placeholderText
        font: control.Style.placeholder.font
        color: control.placeholderTextColor
        visible: !control.length && !control.preeditText && (!control.activeFocus
                || control.horizontalAlignment !== Qt.AlignHCenter)
        elide: Text.ElideRight
    }

    background: Rectangle {
        color: control.Style.background.color
        border.color: control.Style.background.border.color
        border.width: control.Style.background.border.width
        radius: control.Style.background.radius

        Behavior on color { ColorAnimation { duration: 100 }}
    }

    TapHandler {
        id: tapHandler
        onTapped: {
            control.focus = true
            control.clicked()
        }
    }
}
