import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes
import Qt.labs.qmlmodels

import "../components"
import "./delegate"

import Artix.Handlers
import Artix.Models
import Artix.Core
import Artix.Gui

/**
 * @brief Список позиций документа
 */
ListView {
    id: root

    property bool goodsItemDelegateShowImages: false ///< Показывать изображения товаров
    property string goodsItemDelegateImagePlaceholderPath: Style.parameter("icon.goodsPlaceholder") ///< Путь к изображению-заглушке для товаров
    property bool scrollToEndOnItemAdded: false      ///< Прокручивать список к концу при добавлении новой позиции
    property bool interactive: true                  ///< Интерактивные элементы списка (возможность нажатия)
    property bool pinCard: false                     ///< Постоянное отображение данных карты
    property alias withModifiers: dm.withModifiers
    signal storno(var position)
    signal changeQuantity(var position, real value)
    signal consultantDelete(var position)

    // При масштабировании, списки могут отображаться с артефактами.
    // Рендерим с мультисемплированием в нужном разрешении. Не знаю за счет чего, но проблему это решило.
    layer {
        enabled: mainWindow.multisampling
        samples: 2
        textureSize: Qt.size(width * mainWindow.scaleFactor, height * mainWindow.scaleFactor)
    }

    function scrollToEnd() {
        let index = count - 1
        positionViewAtEnd()
        currentIndex = index
    }

    onCountChanged: {
        if (root.scrollToEndOnItemAdded)
            root.scrollToEnd()
    }

    clip: true
    model: DocumentModel { id: dm; hideCard: pinCard }
    // Прикрепленная карта
    headerPositioning: ListView.OverlayHeader
    header: Loader {
        id: contentHeader
        property bool showPinnedCard: object !== undefined && pinCard
        property var object: Session.document.firstActiveCard
        width: root.width
        z: parent.z + 3 // чтобы отображать поверх позиций
        height: showPinnedCard ? item.implicitHeight : 0
        visible: showPinnedCard
        source: showPinnedCard ? "delegate/StyledCardDelegate.qml" : ""
        MouseArea {
            x: 0; y:0; z: parent.item ? parent.item.z + 1 : 0
            width: parent.implicitWidth; height: parent.implicitHeight
        }
    }
    // Выбор делегата в зависимости от типа позиции
    delegate: DelegateChooser {
        role: "type"
        DelegateChoice {
            roleValue: DocumentPositionType.Goods
            delegate: GoodsItemDelegate {
                showImages: root.goodsItemDelegateShowImages
                imagePlaceholderPath: root.goodsItemDelegateImagePlaceholderPath
                interactive: root.interactive
                width: root.width
            }
        }
        DelegateChoice {
            roleValue: DocumentPositionType.Card
            delegate: CardDelegate {
                interactive: root.interactive
                width: root.width
                onClickedStorno: storno(position)
            }
        }
        DelegateChoice {
            roleValue: DocumentPositionType.Coupon
            delegate: CouponDelegate {
                interactive: root.interactive
                width: root.width
            }
        }
        DelegateChoice {
            roleValue: DocumentPositionType.Gift
            delegate: GiftDelegate {
                interactive: root.interactive
                width: root.width
            }
        }
        DelegateChoice {
            roleValue: DocumentPositionType.Modifiers
            delegate: ModifiersDelegate {
                interactive: root.interactive
                width: root.width
            }
        }
    }
    // Блок "Итого"
    // Если одновременно имеются header и footer, по список багует при настройке PullBackFooter.
    // TODO: посмотреть починится ли в новых версиях Qt
    footerPositioning: !pinCard || contentHeight - headerItem.height > height? ListView.PullBackFooter : ListView.OverlayFooter
    footer: GroupBox {
        Style.class: "positionsFooter"
        width: parent.width
        height: implicitContentHeight + topPadding + bottomPadding
        padding: 16
        visible: model.positionsCount > 0
        contentItem: ColumnLayout {
            spacing: 8
            RowLayout {
                BasicLabel {
                    Layout.fillWidth: true
                    Style.class: "positionsFooterName"
                    Tr { code: "positionsDiscout"; defaultMessage: "Сумма скидок" }
                }
                BasicLabel {
                    Layout.fillWidth: true
                    Style.class: "positionsFooterName"
                    text: Utils.formatMoneyItem(Session.document.disc)
                    horizontalAlignment: Text.AlignRight
                }
            }
            RowLayout {
                BasicLabel {
                    Layout.fillWidth: true
                    Style.class: "positionsFooterSum"
                    Tr { code: "positionsSum"; defaultMessage: "Сумма чека" }
                }
                BasicLabel {
                    Layout.fillWidth: true
                    Style.class: "positionsFooterSum"
                    text: Utils.formatMoneyItem(Session.document.sumb)
                    horizontalAlignment: Text.AlignRight
                }
            }
        }
    }
    ScrollBar.vertical: ScrollBar {
        id: scrollBar
        Timer {
            id: scrollTimer
            interval: 2500
            onTriggered: parent.active = false
        }
        onActiveChanged: scrollTimer.start()
    }
}
