import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Models
import Artix.Handlers

/**
 * @brief Боковая панель
 */
SideDialog {
    padding: 0
    closePolicy: Popup.CloseOnPressOutside | Popup.CloseOnEscape
    SideMenuHandler { id: handler }
    implicitWidth: 369

    BasicButton {
        anchors {
            top: parent.top; right: parent.right
            topMargin: 20; rightMargin: 24
        }
        width: 56; height: 56
        radius: width / 2
        Style.class: "sideMenuClose"
        icon: Style.parameter("icon.cross")
        onClicked: close()
    }
    // Сервисное меню. Здесь предполагается использовать действия, которые могут понадобиться в любом контексте.
    // Например действие logout может быть использовано в любом контексте, чтобы заблокировать кассу.
    contentItem: ListView {
        id: listView
        topMargin: 72
        rightMargin: 24
        bottomMargin: 24
        leftMargin: 24
        clip: true
        model: MenuModel {
            Component.onCompleted: refresh(Config.getInt("Gui.SidePanel:menuCode", 0), false)
        }
        delegate: BasicButton {
            Style.class: "sideMenuDelegate"
            textLayout.alignment: Qt.AlignVCenter | Qt.AlignLeft
            width: listView.width
            height: 72
            text: actionName
            onClicked: { handler.executeAction(actionCode); close() }
        }
    }
    background: Rectangle {
        color: Style.parameter("color.modalBackground")
    }

    property bool destroyOnClosed: true
    onClosed: if (destroyOnClosed) destroy()
}
