import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"
import "../"

import Artix.Core
import Artix.Gui

/**
 * @brief Панель добавления товара для панели действий
 */
GridLayout {
    id: root
    rowSpacing: 8
    columnSpacing: 8
    columns: 2
    rows: 6

    signal back()
    signal command(string command, var args)
    signal input(string data)
    property string text

    readonly property real cellWidth: (width - columnSpacing * (columns - 1)) / columns // Ширина кнопки
    readonly property real cellHeight: (height - rowSpacing * (rows - 1)) / rows        // Высота кнопки

    property FormEventFilter eventFilter: FormEventFilter {
        onOk: root.input(root.text)
        onCancel: back()
    }

    Item {
        Layout.preferredHeight: cellHeight
        Layout.row: 0
        Layout.column: 0
    }
    BasicButton {
        Style.class: "actionPanelDelegate20px600"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight
        Layout.row: 1
        Layout.column: 0

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        Tr { code: "actionPanelButtonTmcCatalog"; defaultMessage: "Каталог" }
        icon: Style.parameter("icon.actionPanel.catalog")
        onClicked: root.command("COMMAND_SELECTFROMPICKLIST", { "multilevel": "1" })
    }
    BasicButton {
        Style.class: "actionPanelDelegate20px600"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight
        Layout.row: 2
        Layout.column: 1

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        Tr { code: "actionPanelButtonTmcSearch"; defaultMessage: "Поиск товара" }
        icon: Style.parameter("icon.actionPanel.search")
        onClicked: root.command("COMMAND_SELECTMULTIPLE", { })
    }
    BasicButton {
        Style.class: "actionPanelDelegate20px600"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight
        Layout.row: 3
        Layout.column: 1

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        Tr { code: "actionPanelButtonBack"; defaultMessage: "Назад" }
        onClicked: root.back()
    }
    BasicButton {
        Style.class: "actionPanelDelegateContinue"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight * Layout.rowSpan + rowSpacing * (Layout.rowSpan - 1)
        Layout.row: 4
        Layout.rowSpan: 2
        Layout.column: 1

        textLayout {
            fillWidth: true
            fillHeight: true
        }
        iconLayout {
            alignment: Qt.AlignRight | Qt.AlignTop
            preferredWidth: 32
            preferredHeight: 32
        }
        verticalAlignment: Text.AlignBottom
        Tr { code: "actionPanelButtonAdd"; defaultMessage: "Добавить" }
        icon: Style.parameter("icon.actionPanel.arrow")
        onClicked: root.input(root.text)
    }
    InlineKeyboard {
        Style.class: "actionPanelDelegate"
        Layout.preferredWidth: cellWidth
        Layout.preferredHeight: cellHeight * Layout.rowSpan + rowSpacing * (Layout.rowSpan - 1)
        Layout.row: 2
        Layout.rowSpan: 4
        Layout.column: 0
        layoutType: "digits"
    }
}
