import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes

import "../../components"
import Artix.Gui
import Artix.Core

/**
 * @brief Делегат карты в списке позиций
 */
PositionDelegate {
    signal clickedStorno()
    height: (selected ? contentItem.implicitHeight : cardCommonContent.implicitHeight) + topPadding + bottomPadding
    contentItem: ColumnLayout {
        spacing: 24
        RowLayout {
            id: cardCommonContent
            spacing: 0
            BasicLabel {
                Layout.preferredHeight: 20
                Style.class: "cardDelegateName"
                text: object.card["cardGroup"]["name"] + " № " + object.card["number"]
                verticalAlignment: Text.AlignVCenter
                Layout.fillWidth: true
                elide: Text.ElideRight
            }
            Item { Layout.preferredWidth: 12 }
            BasicLabel {
                Layout.preferredHeight: 20
                Style.class: "cardDelegateBalance"
                leftPadding: 8
                rightPadding: 8
                text: Utils.formatMoneyItem(object.bonusBalance)
                verticalAlignment: Text.AlignVCenter
                opacity: selected ? 0 : 1
                visible: !selected
                Behavior on opacity { OpacityAnimator { duration: 500 } }
            }
            Item { Layout.preferredWidth: 12 }
            Image {
                Layout.preferredWidth: 24
                Layout.preferredHeight: 24
                source: Style.parameter("icon.position.card")
                Component.onCompleted: mainWindow.scaleImage(this)
            }
        }
        ColumnLayout {
            opacity: selected ? 1 : 0
            spacing: 24
            RowLayout {
                spacing: 24
                // Компонент для отображения информации о карте
                ColumnLayout {
                    Layout.alignment: Qt.AlignTop
                    BasicLabel {
                        Layout.preferredWidth: 152
                        Style.class: "cardDelegateBalanceTitle"
                        Tr { code: "positionCardBalance"; defaultMessage: "Баланс" }
                    }
                    BasicLabel {
                        Layout.preferredWidth: 152
                        Style.class: "cardDelegateBalanceValue"
                        text: Utils.formatMoneyItem(object.bonusBalance)
                    }
                }
                // Черта, разделяющая блоки с информацией о карте и информацией о клиенте
                Line {
                    Layout.fillHeight: true
                    strokeStyle: ShapePath.DashLine
                    dashPattern: [3, 4]
                    color: Style.parameter("color.gray")
                    direction: LineDirection.Vertical
                }
                ColumnLayout {
                    Layout.alignment: Qt.AlignTop
                    BasicLabel {
                        Layout.fillWidth: true
                        Style.class: "cardDelegateClientTitle"
                        Tr { code: "positionClientName"; defaultMessage: "Клиент" }
                    }
                    BasicLabel {
                        Layout.fillWidth: true
                        Style.class: "cardDelegateClientValue"
                        text: object.card["client"] && object.card["client"]["name"].length > 0
                              ? object.card["client"]["name"] : " - "
                    }
                    BasicLabel {
                        Layout.fillWidth: true
                        Style.class: "cardDelegatePhoneTitle"
                        Tr { code: "positionClientPhone"; defaultMessage: "Телефон" }
                    }
                    BasicLabel {
                        Layout.fillWidth: true
                        Style.class: "cardDelegatePhoneValue"
                        text: object.card["client"] && object.card["client"]["phoneNumber"].length > 0
                              ? object.card["client"]["phoneNumber"] : " - "
                    }
                }
            }
            BasicButton {
                Layout.preferredWidth: 232
                Layout.preferredHeight: 56
                Layout.alignment: Qt.AlignHCenter
                Style.class: "positionStorno"
                textLayout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
                Tr { code: "positionStorno"; defaultMessage: "Удалить" }
                onClicked: clickedStorno()
            }
            Behavior on opacity { OpacityAnimator { duration: 500 } }
        }
    }    
}
